from MorphologicalAnalysis.MorphologicalParse cimport MorphologicalParse
from MorphologicalAnalysis.State cimport State


cdef class FsmParse(MorphologicalParse):

    cdef list __suffix_list
    cdef list __form_list
    cdef list __transition_list
    cdef list __with_list
    cdef str __initial_pos, __pos, __form, __verb_agreement, __possesive_agreement

    cpdef constructInflectionalGroups(self)
    cpdef str getVerbAgreement(self)
    cpdef str getPossesiveAgreement(self)
    cpdef setAgreement(self, str transitionName)
    cpdef str getLastLemmaWithTag(self, str pos)
    cpdef str getLastLemma(self)
    cpdef addSuffix(self, State suffix, str form, str transition, str withName, str toPos)
    cpdef str getSurfaceForm(self)
    cpdef State getStartState(self)
    cpdef str getFinalPos(self)
    cpdef str getInitialPos(self)
    cpdef setForm(self, str name)
    cpdef State getFinalSuffix(self)
    cpdef str headerTransition(self)
    cpdef str pronounTransition(self)
    cpdef str transitionList(self)
    cpdef str suffixList(self)
    cpdef str withList(self)
    cpdef list getWithList(self)



from Dictionary.TxtWord cimport TxtWord
from MorphologicalAnalysis.FsmParse cimport FsmParse
from MorphologicalAnalysis.State cimport State


cdef class Transition:

    cdef State __to_state
    cdef str __with, __with_name, __to_pos

    cpdef State toState(self)
    cpdef str toPos(self)
    cpdef bint transitionPossibleForString(self, str currentSurfaceForm, str realSurfaceForm)
    cpdef bint transitionPossibleForParse(self, FsmParse currentFsmParse)
    cpdef bint transitionPossibleForWord(self, TxtWord root, State fromState)
    cpdef str __withFirstChar(self)
    cpdef bint __startWithVowelorConsonantDrops(self)
    cpdef bint softenDuringSuffixation(self, TxtWord root)
    cpdef str makeTransitionNoStartState(self, TxtWord root, str stem)
    cpdef str makeTransition(self, TxtWord root, str stem, State startState)
    cpdef str withName(self)



cdef class InflectionalGroup:

    cdef list __IG

    cpdef object getTag(self, int index)
    cpdef int size(self)
    cpdef object containsCase(self)
    cpdef bint containsPlural(self)
    cpdef bint containsTag(self, object tag)
    cpdef bint containsPossessive(self)



from Dictionary.Word cimport Word

from MorphologicalAnalysis.MorphologicalParse cimport MorphologicalParse


cdef class MetamorphicParse:

    cdef list __meta_morpheme_list
    cdef Word __root

    cpdef list getMetaMorphemeTag(self, str tag)
    cpdef Word getWord(self)
    cpdef list getMetaMorphemeTagForParse(self, MorphologicalParse parse, str tag)
    cpdef int size(self)
    cpdef addMetaMorphemeList(self, str newTacticSet)
    cpdef removeMetaMorphemeFromIndex(self, int index)
    cpdef str getMetaMorpheme(self, int index)
